EXPORTS
	?Test2@TestDll2@@SAIXZ @ 1 NONAME ; public: static unsigned int __cdecl TestDll2::Test2(void)
	?Data@TestDll2@@SAHXZ @ 2 NONAME ; public: static int __cdecl TestDll2::Data(void)
	?GlobalAlloc@TestDll2@@SAHH@Z @ 3 NONAME ; public: static int __cdecl TestDll2::GlobalAlloc(int)
	?GlobalAllocated@TestDll2@@SAHXZ @ 4 NONAME ; public: static int __cdecl TestDll2::GlobalAllocated(void)
	?GlobalRead@TestDll2@@SAHHAAVTDes8@@@Z @ 5 NONAME ; public: static int __cdecl TestDll2::GlobalRead(int,class TDes8 &)
	?GlobalWrite@TestDll2@@SAHHABVTDesC8@@@Z @ 6 NONAME ; public: static int __cdecl TestDll2::GlobalWrite(int,class TDesC8 const &)
	?Sem@TestDll2@@SA?AVRSemaphore@@XZ @ 7 NONAME ; public: static class RSemaphore  __cdecl TestDll2::Sem(void)
	?Server@TestDll2@@SAIXZ @ 8 NONAME ; public: static unsigned int __cdecl TestDll2::Server(void)
	?SetData@TestDll2@@SAXH@Z @ 9 NONAME ; public: static void __cdecl TestDll2::SetData(int)
	?Test1@TestDll2@@SAIXZ @ 10 NONAME ; public: static unsigned int __cdecl TestDll2::Test1(void)
	?Attach@TestDll2@@SAHH@Z @ 11 NONAME ; public: static int __cdecl TestDll2::Attach(int)

